import unittest
from sentence_generator import SentenceGenerator


class TestSum(unittest.TestCase):

    def test_generated_sentence(self):
        words_list = [['eat'], ['code', 'commit'], ['sleep']]
        sentences = SentenceGenerator.generate_sentences(words_list)
        self.assertEqual(sentences, ['eat code sleep', 'eat commit sleep'], "Should return all generated sentences")

    def test_empty_words_list(self):
        words_list = []
        sentences = SentenceGenerator.generate_sentences(words_list)
        self.assertEqual(sentences, [], "Should return all generated sentences")


if __name__ == '__main__':
    unittest.main()




class SentenceGenerator(object):

    # Function `generate_sentences` accepts list of lists containing words 
    # Sample input: [ ['eat'], ['code', 'commit'], ['sleep'] ]
    # Returns list of all the possible sentences which can be formed using the words
    # Sample output: [ 'eat code sleep', 'eat commit sleep' ]
    @staticmethod
    def generate_sentences(words_list):
        if not words_list:
            return []

        if len(words_list) == 0:
            return []

        sentences = [""] * len(words_list)
        generated_sentences = []

        for word_index in range(len(words_list[0])):
            SentenceGenerator.sentence_permutations(words_list, 0, word_index, sentences, generated_sentences)

        return generated_sentences

    @staticmethod
    def sentence_permutations(words_list, start_index, word_index, sentences, generated_sentences):

        sentences[start_index] = words_list[start_index][word_index]

        if start_index == len(words_list) - 1:
            generated_sentences.append(' '.join(sentences))
            return
        
        for i in range(len(words_list[start_index + 1])):
            SentenceGenerator.sentence_permutations(words_list, start_index + 1, i, sentences, generated_sentences)




import setuptools

with open("README", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="ak-phrase.py",
    version="1.0.2",
    author="Arshad Kazmi",
    author_email="arshadkazmi42@gmail.com",
    description="Generates permutations of all sentences, using list of words",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/arshadkazmi42/ak-phrase.py",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)",
        "Operating System :: OS Independent",
    ],
)